aboutsummaryrefslogtreecommitdiff
path: root/usr.sbin/periodic
diff options
context:
space:
mode:
authorAlan Somers <asomers@FreeBSD.org>2016-05-21 02:14:11 +0000
committerAlan Somers <asomers@FreeBSD.org>2016-05-21 02:14:11 +0000
commitc5b5b50ded4ee8a57e22f75ad880ccef9ed8f95a (patch)
tree29679b7b3828de6f1776bb4d7619840849d2b146 /usr.sbin/periodic
parenta9da9b86d0194f45d24f03ba32923654f5145ffa (diff)
Notes
Diffstat (limited to 'usr.sbin/periodic')
-rw-r--r--usr.sbin/periodic/periodic.89
-rw-r--r--usr.sbin/periodic/periodic.sh4
2 files changed, 7 insertions, 6 deletions
diff --git a/usr.sbin/periodic/periodic.8 b/usr.sbin/periodic/periodic.8
index 175119de5a39..b7bfdf6d7a06 100644
--- a/usr.sbin/periodic/periodic.8
+++ b/usr.sbin/periodic/periodic.8
@@ -24,7 +24,7 @@
.\"
.\" $FreeBSD$
.\"
-.Dd August 30, 2007
+.Dd May 20, 2016
.Dt PERIODIC 8
.Os
.Sh NAME
@@ -166,8 +166,9 @@ table
the top level directory containing
.Pa daily ,
.Pa weekly ,
+.Pa monthly ,
and
-.Pa monthly
+.Pa security
subdirectories which contain standard system periodic executables
.It Pa /etc/defaults/periodic.conf
the
@@ -175,9 +176,9 @@ the
system registry contains variables that control the behaviour of
.Nm
and the standard
-.Pa daily , weekly ,
+.Pa daily , weekly , monthly ,
and
-.Pa monthly
+.Pa security
scripts
.It Pa /etc/periodic.conf
this file contains local overrides for the default
diff --git a/usr.sbin/periodic/periodic.sh b/usr.sbin/periodic/periodic.sh
index c27aeee1d309..b2605200f79e 100644
--- a/usr.sbin/periodic/periodic.sh
+++ b/usr.sbin/periodic/periodic.sh
@@ -4,13 +4,13 @@
#
# Run nightly periodic scripts
#
# usage: periodic { daily | weekly | monthly } - run standard periodic scripts
# periodic /absolute/path/to/directory - run periodic scripts in dir
#
usage () {
echo "usage: $0 <directory of files to execute>" 1>&2
- echo "or $0 { daily | weekly | monthly }" 1>&2
+ echo "or $0 { daily | weekly | monthly | security }" 1>&2
exit 1
}
@@ -4,13 +4,13 @@
# Run nightly periodic scripts
#
-# usage: periodic { daily | weekly | monthly } - run standard periodic scripts
+# usage: periodic { daily | weekly | monthly | security } - run standard scripts
# periodic /absolute/path/to/directory - run periodic scripts in dir
#